package com.ippon.article.clientmobile;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

import com.couchbase.lite.CouchbaseLiteException;
import com.couchbase.lite.Result;
import com.ippon.article.clientmobile.database.DatabaseManagement;

import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class ArticleActivity extends AppCompatActivity {

    private final static String TAG = "ArticleApp";

    private final static String GATEWAY_URL = "ws://10.0.2.2:4984/";

    private final static String GATEWAY_DB = "app";

    private final static String GATEWAY_USER = "agile";

    private final static String GATEWAY_PWD = "agile";

    private final DatabaseManagement databaseManagement = new DatabaseManagement();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_article);

        TextView tag = findViewById(R.id.tag);

        tag.setText(GATEWAY_USER);
    }

    @Override
    protected void onStart() {
        super.onStart();

        initDatabase();

        updateArticleView();

        initCleanButton();

    }

    private void initCleanButton() {
        Button clickButton = findViewById(R.id.clean);
        clickButton.setOnClickListener(button -> {
            try {
                databaseManagement.deleteDatabase();

                initDatabase();

                updateArticleView();
            } catch (CouchbaseLiteException e) {
                Log.e(TAG, "Database deletion", e);
            }

        });
    }

    private void initDatabase() {
        // Init & Configure database
        try {
            databaseManagement.openDatabase(this.getApplicationContext(), e -> updateArticleView());

            databaseManagement.configureReplication(GATEWAY_URL + GATEWAY_DB, GATEWAY_USER, GATEWAY_PWD);

        } catch (CouchbaseLiteException e) {
            Log.e(TAG, "Application startup", e);
        } catch (URISyntaxException uri) {
            Log.e(TAG, "Gateway URL syntax problem", uri);
        }
    }

    private void updateArticleView() {
        List<String> updatedItems = loadArticles();
        fillArticles(updatedItems);
    }

    private List<String> loadArticles() {
        List<Result> results = Collections.emptyList();
        try {
            results = databaseManagement.findAllDocuments("com.ippon.article.couchbase.server.article.Article");
        } catch (CouchbaseLiteException e) {
            Log.e(TAG, "Refresh documents from database", e);
        }

        Log.i(TAG, "----------RESULTS---------" + results.size());
        List<String> items = new ArrayList<>();

        for (Result result : results) {
            Log.i(TAG, "------------------------");
            if (result.getString("content") != null) {
                Log.i(TAG, result.getString("content"));
                items.add(result.getString("content"));
            }

        }
        return items;
    }

    private void fillArticles(List<String> items) {
        ListView articleView = findViewById(R.id.articles);
        ArrayAdapter<String> itemsAdapter =
                new ArrayAdapter<>(this, android.R.layout.simple_list_item_1, items);
        articleView.setAdapter(itemsAdapter);
    }


}
